@@ -202,27 +202,38 @@
             MLAlbum *album = nil;
 
             BOOL wasCreated = NO;
-            MLAlbumTrack *track = [MLAlbumTrack trackWithAlbumName:albumName
-                                                       trackNumber:@([trackNumber integerValue])
-                                                         trackName:title
-                                                    createIfNeeded:YES
-                                                        wasCreated:&wasCreated];
-            if (track) {
-                album = track.album;
-                track.title = title ? title : @"";
-                track.artist = artist ? artist : @"";
-                track.genre = genre ? genre : @"";
-                album.releaseYear = releaseYear ? releaseYear : @"";
+            @try {
+                MLAlbumTrack *track = [MLAlbumTrack trackWithAlbumName:albumName
+                                                           trackNumber:@([trackNumber integerValue])
+                                                             trackName:title
+                                                        createIfNeeded:YES
+                                                            wasCreated:&wasCreated];
+                if (track) {
+                    album = track.album;
+                    track.title = title ? title : @"";
+                    track.artist = artist ? artist : @"";
+                    track.genre = genre ? genre : @"";
+                    album.releaseYear = releaseYear ? releaseYear : @"";
 
-                if (!track.title || [track.title isEqualToString:@""])
-                    track.title = [MLTitleDecrapifier decrapify:file.title];
+                    if (!track.title || [track.title isEqualToString:@""])
+                        track.title = [MLTitleDecrapifier decrapify:file.title];
 
-                [track addFilesObject:file];
-                file.albumTrack = track;
+                    [track addFilesObject:file];
+                    file.albumTrack = track;
+                }
+            }
+            @catch (NSException *exception) {
+                APLog(@"album track creation failed");
             }
         }
 
-        file.type = kMLFileTypeAudio;
+        @try {
+            file.type = kMLFileTypeAudio;
+        }
+        @catch (NSException *exception) {
+            APLog(@"file type setting failed");
+        }
+
         APLog(@"'%@' is an audio file, fetching artwork", file.title);
         NSString *artist, *albumName, *title;
         BOOL skipOperation = NO;
@@ -241,31 +252,40 @@
             NSDictionary *poorMansContentInfo = [MLTitleDecrapifier audioContentInfoFromFile:file];
             if (poorMansContentInfo)
                 title = poorMansContentInfo[VLCMetaInformationTitle];
-            file.title = title;
+            @try {
+                file.title = title;
+            }
+            @catch (NSException *exception) {
+                APLog(@"file title setting failed");
+            }
         }
 
         if (!skipOperation) {
-            NSString *artworkPath = [self artworkPathForMediaItemWithTitle:title Artist:artist andAlbumName:albumName];
-            if ([[NSFileManager defaultManager] fileExistsAtPath:artworkPath]) {
-                file.computedThumbnail = [UIImage scaleImage:[UIImage imageWithContentsOfFile:artworkPath]
-                                                   toFitRect:(CGRect){CGPointZero, [UIImage preferredThumbnailSizeForDevice]}];
+            @try {
+                NSString *artworkPath = [self artworkPathForMediaItemWithTitle:title Artist:artist andAlbumName:albumName];
+                if ([[NSFileManager defaultManager] fileExistsAtPath:artworkPath]) {
+                    file.computedThumbnail = [UIImage scaleImage:[UIImage imageWithContentsOfFile:artworkPath]
+                                                       toFitRect:(CGRect){CGPointZero, [UIImage preferredThumbnailSizeForDevice]}];
+                }
+                if (file.computedThumbnail == nil)
+                    file.albumTrack.containsArtwork = NO;
+            }
+            @catch (NSException *exception) {
+                APLog(@"file thumbnail setting failed");
             }
-            if (file.computedThumbnail == nil)
-                file.albumTrack.containsArtwork = NO;
         }
     } else {
         MLMediaLibrary *sharedLibrary = [MLMediaLibrary sharedMediaLibrary];
         [sharedLibrary computeThumbnailForFile:file];
         [sharedLibrary fetchMetaDataForFile:file];
-
-        NSDictionary *attributes = [[NSFileManager defaultManager] attributesOfItemAtPath:file.url.absoluteString error:nil];
-        NSNumber *size = attributes[NSFileSize]; // FIXME [result valueForAttribute:@"kMDItemFSSize"];
-        if ([size longLongValue] < 150000000) /* 150 MB */
-            file.type = kMLFileTypeClip;
-        else
-            file.type = kMLFileTypeMovie;
     }
-    file.hasFetchedInfo = @(YES);
+    @try {
+        file.hasFetchedInfo = @(YES);
+    }
+    @catch (NSException *exception) {
+        APLog(@"failed to set that we fetch info for the file");
+    }
+
     [self endParsing];
 }
 
